@@ -28,7 +28,7 @@ eval 'use Devel::GlobalDestruction';
 our @ISA = qw(Exporter);
 our @EXPORT = qw(@ALL_JOBS %ALL_JOBS PREFORK POSTFORK 
                  POSTFORK_PARENT POSTFORK_CHILD);
-our $VERSION = '0.79';
+our $VERSION = '0.80';
 
 our (@ALL_JOBS, %ALL_JOBS, @ARCHIVED_JOBS, $WIN32_PROC, $WIN32_PROC_PID);
 our $OVERLOAD_ENABLED = 0;
@@ -1025,8 +1025,8 @@ sub _postlaunch_child_to_cmd {
                 "Child process unable to create new fork to run cmd";
         }
 	if ($$ != $this_pid) {
-	    exec( @{$job->{cmd}} )
-		or Carp::confess 'exec for cmd-style fork failed ';
+	    exec( @{$job->{cmd}} ) or
+                Carp::confess 'exec for cmd-style fork failed ';
 	}
 	$job->set_signal_pid($exec_pid);
 	$job->{exec_pid} = $exec_pid;
@@ -1085,7 +1085,7 @@ sub _postlaunch_child_to_remote_cmd {
             print STDOUT <$out>;
             print STDERR <$err>;
             deinit_child();
-            debug("waitpid returned $z, exit code of $$ was $c1 ", $c1>>8)
+            debug("waitpid returned $z, exit code for $$ was $c1 ", $c1>>8)
                 if $job->{debug};
             exit $c1 >> 8;
         } elsif (CONFIG_module("Net::SSH::Perl")) {
@@ -1858,10 +1858,10 @@ END {
 	Forks::Super::Queue::_cleanup();
 	Forks::Super::Job::Ipc::_cleanup();
     } else {
-	if (defined($this) && defined($this->{_cleanup_code})) {
-	    no strict 'refs';
-	    $this->{_cleanup_code}->();
-	}
+        if (defined($this) && defined($this->{_cleanup_code})) {
+            no strict 'refs';
+            $this->{_cleanup_code}->();
+        }
 	Forks::Super::Job::Timeout::_cleanup_child();
     }
 }
@@ -2276,7 +2276,7 @@ Forks::Super::Job - object representing a background task
 
 =head1 VERSION
 
-0.79
+0.80
 
 =head1 SYNOPSIS
 
