@@ -10,7 +10,7 @@ use Carp;
 use strict;
 use warnings;
 
-our $VERSION = '0.79';
+our $VERSION = '0.80';
 
 # "protocols" for serializing data and the methods used
 # to carry out the serialization
@@ -23,18 +23,6 @@ my %serialization_dispatch = (
 	decode => sub { return YAML::Load($_[0]) }
     },
 
-    JSON1 => {
-	require => sub { require JSON },
-	encode => sub { return JSON->new->objToJson( \@_ ); },
-	decode => sub { return JSON->new->jsonToObj($_[0]) }
-    },
-
-    JSON2 => {
-	require => sub { require JSON },
-	encode => sub { return JSON::encode_json( \@_ ); },
-	decode => sub { return JSON::decode_json($_[0]) }
-    },
-
     'Data::Dumper' => {
 	require => sub { require Data::Dumper },
 	encode => sub { return Data::Dumper::Dumper( \@_ ) },
@@ -57,12 +45,6 @@ my %serialization_dispatch = (
 	}
     },
 
-    'YAML::Tiny' => {
-	require => sub { require YAML::Tiny },
-	encode => sub { return YAML::Tiny::Dump( \@_ ) },
-	decode => sub { return YAML::Tiny::Load($_[0]) }
-    },
-
     );
 
 # an array that is evaluated in a child process.
@@ -104,7 +86,7 @@ sub _encode {
 	return $serialization_dispatch{$protocol}{encode}->(@data);
     } else {
 	croak 'Forks::Super::LazyEval::BackgroundScalar: ',
-	    'YAML, JSON, or Data::Dumper required to use bg_eval';
+	    'YAML or Data::Dumper required to use bg_eval';
     }
 }
 
@@ -115,7 +97,7 @@ sub _decode {
 	return $serialization_dispatch{$protocol}{decode}->($data,$job);
     } else {
 	croak 'Forks::Super::LazyEval::BackgroundScalar: ',
-	    'YAML, JSON, or Data::Dumper required to use bg_eval';
+	    'YAML or Data::Dumper required to use bg_eval';
     }
 }
 
@@ -204,7 +186,7 @@ Forks::Super::LazyEval::BackgroundArray
 
 =head1 VERSION
 
-0.79
+0.80
 
 =head1 DESCRIPTION
 
