@@ -7,6 +7,7 @@
 
 package Forks::Super::LazyEval::BackgroundScalar;
 use Forks::Super;
+use Forks::Super::Debug qw(:all);
 use Forks::Super::Wait 'WREAP_BG_OK';
 use Scalar::Util 'reftype';
 use Carp;
@@ -58,7 +59,7 @@ use overload # XXX - what is overloading for? is it necessary?
 		         : atan2($_[0]->_fetch, $_[1]) }
 ;
 
-our $VERSION = '0.79';
+our $VERSION = '0.80';
 
 # "protocols" for serializing data and the methods used
 # to carry out the serialization
@@ -71,36 +72,6 @@ my %serialization_dispatch = (
 	decode => sub { return YAML::Load($_[0]) }
     },
 
-    JSON1 => {
-	require => sub { require JSON },
-	encode => sub {
-	    my $data = shift;
-	    if (ref $data eq '') {
-		$data = "$data";
-	    } elsif (ref($data) ne reftype($data)) {
-                croak "bg_eval: cannot use JSON to serialize "
-                    . "return value of type ", ref($data);
-            }
-	    return JSON->new->objToJson([$data]);
-	},
-	decode => sub { return JSON->new->jsonToObj($_[0])->[0] }
-    },
-
-    JSON2 => {
-	require => sub { require JSON },
-	encode => sub { 
-	    my $data = shift;
-	    if (ref $data eq '') {
-		$data = "$data";
-	    } elsif (ref($data) ne reftype($data)) {
-                croak "bg_eval: cannot use JSON to serialize "
-                    . "return value of type ", ref($data);
-	    }
-	    return JSON::encode_json([$data]);
-	},
-	decode => sub { return JSON::decode_json($_[0])->[0] }
-    },
-
     'Data::Dumper' => {
 	require => sub { require Data::Dumper },
 	encode => sub { return Data::Dumper::Dumper($_[0]) },
@@ -123,12 +94,6 @@ my %serialization_dispatch = (
 	}
     },
 
-    'YAML::Tiny' => {
-	require => sub { require YAML::Tiny },
-	encode => sub { return YAML::Tiny::Dump($_[0]) },
-	decode => sub { return YAML::Tiny::Load($_[0]) }
-    },
-
     );
 
 # a scalar reference that is evaluated in a child process.
@@ -183,7 +148,7 @@ sub _encode {
 	return $serialization_dispatch{$protocol}{encode}->($data);
     } else {
 	croak 'Forks::Super::LazyEval::BackgroundScalar: ',
-	    'YAML, JSON, or Data::Dumper required to use bg_eval';
+	    'YAML or Data::Dumper required to use bg_eval';
     }
 }
 
@@ -194,7 +159,7 @@ sub _decode {
 	return $serialization_dispatch{$protocol}{decode}->($data,$job);
     } else {
 	croak 'Forks::Super::LazyEval::BackgroundScalar: ',
-	    'YAML, JSON, or Data::Dumper required to use bg_eval';
+	    'YAML or Data::Dumper required to use bg_eval';
     }
 }
 
@@ -237,10 +202,10 @@ sub _fetch {
 
     if (!$self->{value_set}) {
 	if (!$self->{job}->is_complete) {
+            return if $Forks::Super::Job::INSIDE_END_QUEUE;
 	    my $pid = Forks::Super::waitpid $self->{job_id}, WREAP_BG_OK;
             no warnings 'numeric';
 	    if ($pid != $self->{job}{real_pid} && $pid != $self->{job}{pid}) {
-
 		carp 'Forks::Super::bg_eval: ',
 			"failed to retrieve result from process!\n";
 		$self->{value_set} = 1;
@@ -253,7 +218,7 @@ sub _fetch {
 		$self->{error} = 'job status: ' . $self->{job}{status};
 	    }
 	    # XXX - what other error conditions are there to set ?
-	}
+        }
 
 	if ($self->{style} eq 'eval') {
 	    my $stdout = join'', Forks::Super::read_stdout($self->{job_id});
@@ -301,7 +266,7 @@ Forks::Super::LazyEval::BackgroundScalar
 
 =head1 VERSION
 
-0.79
+0.80
 
 =head1 DESCRIPTION
 
