@@ -21,7 +21,7 @@ use warnings;
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(wait waitpid waitall TIMEOUT WREAP_BG_OK);
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
-our $VERSION = '0.79';
+our $VERSION = '0.80';
 
 my ($productive_waitpid_code);
 my $respect_SIGCHLD_ignore = 1;
@@ -402,6 +402,9 @@ sub _block_until_job_completes {
 	if ($job->{state} =~ /DEFER|SUSPEND/) {
 	    Forks::Super::Queue::check_queue();
 	}
+        if ($DEBUG > 1) {
+            debug("    blocking on $job state is $job->{state}");
+        }
     }
     return 0;
 }
@@ -528,7 +531,7 @@ Forks::Super::Wait
 
 =head1 VERSION
 
-0.79
+0.80
 
 =head1 DESCRIPTION
 
